==> lulo-3.0.0.tgz: package/README.md <==
# lulo

[![npm version](https://badge.fury.io/js/lulo.svg)](https://badge.fury.io/js/lulo)
[![Build Status](https://travis-ci.org/carlnordenfelt/lulo.svg?branch=master)](https://travis-ci.org/carlnordenfelt/lulo)
[![Coverage Status](https://coveralls.io/repos/github/carlnordenfelt/lulo/badge.svg?branch=master)](https://coveralls.io/github/carlnordenfelt/lulo?branch=master)
[![Known Vulnerabilities](https://snyk.io/test/github/carlnordenfelt/lulo/badge.svg?targetFile=package.json)](https://snyk.io/test/github/carlnordenfelt/lulo?targetFile=package.json)

lulo is a tiny plugin based framework for working with AWS CloudFormation Custom Resources.
The purpose of lulo is to promote reuse of logic written for CustomResources and thus really make AWS CloudFormation as powerful as it can be.

With just a few lines of code you are ready to use all [published plugins](https://carlnordenfelt.github.io/lulo/plugins.html)
and if you can't find what you need,
plugins are easy to write and can be either be published as npm modules
or be used a plain nodejs modules in your own project.

The goal is of course to build a substantial plugin repository so please, contribute! :)

## Installation
```
$ npm i lulo --save
```
For more information and a listing of all plugins, [visit the project page](https://carlnordenfelt.github.io/lulo)
A complete example implementation can be found [here](https://github.com/carlnordenfelt/lulo/tree/master/example)

## Writing plugins
A write up on [how to write plugins](https://carlnordenfelt.github.io/lulo/writing-plugins.html) can also be found at the project page.

## Why Lulo?
Because it's a [very healthy fruit](https://en.wikipedia.org/wiki/Solanum_quitoense) :)

## License
[The MIT License (MIT)](/LICENSE)

## Change Log
[Change Log](/CHANGELOG.md)

==> lulo-3.1.0.tgz: package/README.md <==
# lulo

[![npm version](https://badge.fury.io/js/lulo.svg)](https://badge.fury.io/js/lulo)
[![Build Status](https://travis-ci.org/carlnordenfelt/lulo.svg?branch=master)](https://travis-ci.org/carlnordenfelt/lulo)
[![Coverage Status](https://coveralls.io/repos/github/carlnordenfelt/lulo/badge.svg?branch=master)](https://coveralls.io/github/carlnordenfelt/lulo?branch=master)
[![Known Vulnerabilities](https://snyk.io/test/github/carlnordenfelt/lulo/badge.svg?targetFile=package.json)](https://snyk.io/test/github/carlnordenfelt/lulo?targetFile=package.json)

lulo is a tiny plugin based framework for working with AWS CloudFormation Custom Resources.
The purpose of lulo is to promote reuse of logic written for CustomResources.

With just a few lines of code you are ready to use all [published plugins](https://carlnordenfelt.github.io/lulo/plugins.html)
and if you can't find what you need,
plugins are easy to write and can be either be published as npm modules
or be used a plain nodejs modules exported within your own project.

The goal is of course to build a substantial plugin repository so please, contribute!

## Installation
```
$ npm i lulo --save
```
For more information and a listing of all plugins, [visit the project page](https://carlnordenfelt.github.io/lulo)
A complete example implementation can be found [here](https://github.com/carlnordenfelt/lulo/tree/master/example)

## Writing plugins
A write up on [how to write plugins](https://carlnordenfelt.github.io/lulo/writing-plugins.html) can also be found at the project page.

## Why Lulo?
Because it's a [very healthy fruit](https://en.wikipedia.org/wiki/Solanum_quitoense) :)

## License
[The MIT License (MIT)](/LICENSE)

## Change Log
[Change Log](/CHANGELOG.md)
